require 'json'
require 'calculator.rb'

class JSONThermostat
  attr_accessor :current_value, :wanted_value, :range
  attr_accessor :setting_unit, :measurment_unit
  # Initialize the thermostats wanted value, range and unit.
  # @param [JSON] takes wanted value, range and unit from JSON input.

  def initialize(setjson)
    to_parse = JSON.parse(setjson)
    @wanted_value = to_parse['temperature']
    @range = to_parse['range'] / 2.0
    @setting_unit = to_parse['unit']
  end
  # Update the current value and his unit.
  # @param [JSON] takes current value an unit from JSON input.

  def update(setjson)
    to_parse = JSON.parse(setjson)
    @current_value = to_parse['temperature']
    @measurment_unit = to_parse['unit']
    args = { unit: setting_unit, value: wanted_value }
    @wanted_value = calculator.calc_setting(args)
    args = { unit: measurment_unit, value: current_value }
    @current_value = calculator.calc_setting(args)
    check
  end

  # Checks the current value by the wanted value and set on the heating or airco

  def check
    if @current_value > (wanted_value + range)
      set_airco
    elsif @current_value < (wanted_value - range)
      set_heating
    else
      everything_off
    end
  end

  def calculator
    @calculator ||= Calculator.new
  end

  def set_airco
    '{\'cooling\':true,\'heating\':false}'
  end

  def set_heating
    '{\'cooling\':false,\'heating\':true}'
  end

  def everything_off
    '{\'cooling\':false,\'heating\':false}'
  end
end
